'''
restore-mail-inject.py - Tool to inject mails via IMAP

Copyright (c) 2012 Intra2net AG
'''

import argparse
from mail_iterator import MailIterator
from file_iterator import FileIterator

def main():
    """Main function."""

    # prepare configuration
    args = configure_args()
    print("The module restore_mail_inject.py started with user %s, folder %s and source %s." %
          (args.user, args.folder, args.srcdir))

    # connect
    try:
        session = MailIterator("gwt-intranator.m.i2n", "mit.punkt", "mit.punkt")
        #session = MailIterator("/var/imap/socket/imap", "cyrus", "geheim")
        storage = FileIterator(args.mboxlist)
    except UserWarning:
        print("Couldn't connect to IMAP server.")
        return

    # delete olf IMAP folders if no append requested
    if(not args.append):
        session.delete_mailboxes(args.folder)
        if(args.folder == "INBOX"):
            session.clear_inbox_acls(args.user)

    # inject emails
    path_generator = storage.load_mails(args.srcdir, args.folder)
    for message, mailbox, date_modified in path_generator:
        for new_mailbox in storage.created_mailboxes:
            session.create_mailbox(new_mailbox)
        for acl_mailbox in storage.acl_mailboxes:
            session.add_acls(acl_mailbox, args)
        session.inject_message(message, mailbox, date_modified)
        # add acls after all subfolders or their acls will be derived from parent folder

    print("Finished injecting mails.")

    return

def configure_args():
    """Configure arguments and return them."""
    # parse arguments
    parser = argparse.ArgumentParser(description="Tool to inject mails via IMAP.")
    parser.add_argument('-u', '--username', dest='user', action='store',
                        required=True, help='user to store mails to')
    parser.add_argument('-f', '--foldername', dest='folder', action='store',
                        default="INBOX", help='folder to store mails to - if not specified we overwrite INBOX')
    parser.add_argument('-s', '--sourcedir', dest='srcdir', action='store',
                        required=True, help='folder to read mail from')
    parser.add_argument('-m', '--mboxlist', dest='mboxlist', action='store',
                        default="", help='mboxlist file (flat file format) to read the ACLs from')
    parser.add_argument('-o', '--ouser', dest='ouser', action='store',
                        default="", help='name of the original user (=username if not specified)')
    parser.add_argument('-a', '--append', dest='append', action='store_true',
                        default=False, help="append mails, don't delete anything")
    args = parser.parse_args()

    if (args.folder != "INBOX"):
        args.folder = "INBOX/" + args.folder
    if (args.ouser == ""):
        args.ouser = args.user

    return args


if(__name__ == "__main__"):
    main()
